@@ -442,7 +442,8 @@ where
                                             ident: ident.clone(),
                                             class,
                                             declare: false,
-                                        },
+                                        }
+                                        .fold_with(self),
                                     ))));
 
                                     extra_stmts.push(
@@ -870,6 +871,15 @@ where
         node.fold_children_with(self)
     }
 
+    fn fold_class_decl(&mut self, node: ClassDecl) -> ClassDecl {
+        self.scope
+            .borrow_mut()
+            .declared_vars
+            .push((node.ident.sym.clone(), node.ident.span.ctxt()));
+
+        node.fold_children_with(self)
+    }
+
     mark_as_nested!();
 }
 
